@@ -3,12 +3,13 @@ from loguru import logger
 from brats.core.inpainting_algorithms import Inpainter
 from brats.core.missing_mri_algorithms import MissingMRI
 from brats.core.segmentation_algorithms import (
-    AdultGliomaPostTreatmentSegmenter,
     AdultGliomaPreTreatmentSegmenter,
+    AdultGliomaPreAndPostTreatmentSegmenter,
     AfricaSegmenter,
     GoATSegmenter,
     MeningiomaSegmenter,
     MetastasesSegmenter,
+    MeningiomaRTSegmenter,
     PediatricSegmenter,
 )
 
